##############################################
#
# Effects of drought selection X history of 
# functional group richness in Jena 
# on biodiversity effects on productivity
# Corresponds to the results in Supplementary 
# Data 4 - 5
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-01-03 
#
##############################################

rm(list = ls())
library(asreml)
library(pascal)

# read data of net biodiversity effects (NE) 
# on productivity, which were partitioned
# into complementarity effects (CE) and
# selection effects (SE)
dat = read.csv("div-productivity_data.csv")
str(dat)
summary(dat[,c("NE", "CE", "SE")])
table(dat$Block)
nlevels(as.factor(dat$sp_comp))
# biodiversity effects were calculated
# separately for each harvest: pre drought,
# during drought and post drought.
table(dat$time)

# history of functional group richness in the field
summary(dat$FGR_history)
length(unique(dat$Pot[is.na(dat$FGR_history)]))
# remove NA of FGR_history (13 pots)
dat = subset(dat, !is.na(FGR_history))
# fit FGR_history in linear (Supplementary 
# Data 4) or log-linear (Supplementary 
# Data 5) form
dat$FGR_history = as.numeric(scale(dat$FGR_history))
#dat$FGR_history = as.numeric(scale(log2(dat$FGR_history)))

###################################
# 1. Pre-drought
d1 = subset(dat, time == "Pre-drought")
str(d1)

#-------------------------
#     NE
#-------------------------
tapply(d1$NE, d1$drought, mean, na.rm = T)
sum(!is.na(d1$NE))

# effects of drought selection on NE
lmm1 = asreml.nvc(NE ~
                Block
              + drought
              + FGR_history
              + drought:FGR_history,
              random = ~ sp_comp
              + sp_comp:drought,
              keep.order = T, data = d1)
lmm1 = update(lmm1)
lmm1 = update(lmm1)
test.asreml(lmm1) 

#-------------------------
#     CE
#-------------------------
tapply(d1$sqrt_CE, d1$drought, mean, na.rm = T)
sum(!is.na(d1$sqrt_CE))

# effects of drought selection on CE
lmm1 = asreml.nvc(sqrt_CE ~
                Block
              + drought
              + FGR_history
              + drought:FGR_history,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d1)
lmm1 = update(lmm1)
test.asreml(lmm1)

#-------------------------
#     SE
#-------------------------
tapply(d1$sqrt_SE, d1$drought, mean, na.rm = T)
sum(!is.na(d1$sqrt_SE))

# effects of drought selection on SE
lmm1 = asreml.nvc(sqrt_SE ~
                Block
              + drought
              + FGR_history
              + FGR_history:drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d1)
lmm1 = update(lmm1)
test.asreml(lmm1)

###############################################
# 2. During-drought
d2 = subset(dat, time == "Drought")
str(d2)

#-------------------------
#     NE
#-------------------------
tapply(d2$NE, d2$drought, mean, na.rm = T)
sum(!is.na(d2$NE))

# effects of drought selection on NE
lmm1 = asreml.nvc(NE ~
                Block
              + drought
              + FGR_history
              + FGR_history:drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d2)
lmm1 = update(lmm1)
test.asreml(lmm1) 

#-------------------------
#     CE
#-------------------------
tapply(d2$sqrt_CE, d2$drought, mean, na.rm = T)
sum(!is.na(d2$sqrt_CE))

lmm1 = asreml.nvc(sqrt_CE ~
                Block
              + drought
              + FGR_history
              + FGR_history:drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d2)
lmm1 = update(lmm1)
test.asreml(lmm1) 

#-------------------------
#     SE
#-------------------------
tapply(d2$sqrt_SE, d2$drought, mean, na.rm = T)
sum(!is.na(d2$sqrt_SE))

lmm1 = asreml.nvc(sqrt_SE ~
                Block
              + drought
              + FGR_history
              + FGR_history:drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d2)
lmm1 = update(lmm1)
test.asreml(lmm1) 

###############################################
# 3. Post-drought
d3 = subset(dat, time == "Post-drought")
str(d3)

#-------------------------
#     NE
#-------------------------
tapply(d3$NE, d3$drought, mean, na.rm = T)
sum(!is.na(d3$NE))

lmm1 = asreml.nvc(NE ~
                Block
              + drought
              + FGR_history
              + FGR_history:drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d3)
lmm1 = update(lmm1)
test.asreml(lmm1) 

#-------------------------
#     CE
#-------------------------
tapply(d3$sqrt_CE, d3$drought, mean, na.rm = T)
sum(!is.na(d3$sqrt_CE))

lmm1 = asreml.nvc(sqrt_CE ~
                Block
              + drought
              + FGR_history
              + FGR_history:drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d3)
lmm1 = update(lmm1)
lmm1 = update(lmm1)
test.asreml(lmm1) 

# lmm1 using asreml.nvc or asreml cause problem,
# so that we use aov instead

aov1 = aov(terms(sqrt_CE ~
                   Block +
                   sp_comp +
                   drought +
                   FGR_history +
                   drought:sp_comp +
                   drought:FGR_history,
                 keep.order = T),
           data = d3)
summary(aov1)
aov.ftest(aov1, drought~sp_comp:drought, 
          table = T)

#-------------------------
#     SE
#-------------------------
tapply(d3$sqrt_SE, d3$drought, mean, na.rm = T)
sum(!is.na(d3$sqrt_SE))

lmm1 = asreml.nvc(sqrt_SE ~
                Block
              + drought
              + FGR_history
              + FGR_history:drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d3)
test.asreml(lmm1) 

