###########################################
#
# ANOVA for the effects of drought selection
# on the difference in interation intensities
# between mixture and monoculture
# in other words, the effects of drought selection
# on the difference between heterospecific and
# conspecific interactions
# Corresponds to the results in Fig. 4, 
# and Supplementary Tables 7-8
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-04-25
#
###########################################

rm(list = ls())
library(asreml)
library(pascal)

dat = read.csv("div-interaction_data.csv")
str(dat)
# note: Fig. 4 was produced from the raw data
# in this csv file by calculating the average
# difference in interaction intensity (Ndiff)
# for each species composition of each selection
# treatment in each harvest time.

# summary statistics
summary(dat$Ndiff)
dat0 = subset(dat, !is.na(Ndiff))
with(dat0, tapply(Ndiff,
                  list(drought, time),
                  mean))
with(dat0, tapply(Ndiff,
                  list(drought, time),
                  length))
with(dat0, tapply(Ndiff, time, length))

#------------------------------
#
#    1. Pre-drought
#
#------------------------------
d1 = subset(dat0, time == "Pre-drought")

# effects of drought selection on the difference
# in neighbor interaction intensities
lmm1 = asreml.nvc(Ndiff ~
                    Block
                  + drought,
                  random = ~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d1)
lmm1 = update(lmm1)
test.asreml(lmm1) 

# test the significance of interaction difference
# separately for each selection treatment
d1d = subset(d1, drought == "D")
d1r = subset(d1, drought == "R")

lmm1_1 = asreml.nvc(Ndiff ~
                    Block,
                  random = ~sp_comp,
                  data = d1d)
test.asreml(lmm1_1)

lmm1_2 = asreml.nvc(Ndiff ~
                    Block,
                  random = ~sp_comp,
                  data = d1r)
lmm1_2 = update(lmm1_2)
test.asreml(lmm1_2)

#------------------------------
#
#    2. During drought
#
#------------------------------
d2 = subset(dat0, time == "Drought")

# effects of drought selection on the difference
# in neighbor interaction intensities
lmm1 = asreml.nvc(Ndiff ~
                    Block
                  + drought,
                  random = ~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d2)
lmm1 = update(lmm1)
test.asreml(lmm1) 

# test the significance of interaction difference
# separately for each selection treatment
d2d = subset(d2, drought == "D")
d2r = subset(d2, drought == "R")

lmm1_1 = asreml.nvc(Ndiff ~
                      Block,
                    random = ~sp_comp,
                    data = d2d)
lmm1_1 = update(lmm1_1)
lmm1_1 = update(lmm1_1)
test.asreml(lmm1_1)

lmm1_2 = asreml.nvc(Ndiff ~
                      Block,
                    random = ~sp_comp,
                    data = d2r)
test.asreml(lmm1_2)

#------------------------------
#
#    3. Post drought
#
#------------------------------
d3 = subset(dat0, time == "Post-drought")

# effects of drought selection on the difference
# in neighbor interaction intensities
lmm1 = asreml.nvc(Ndiff ~
                    Block
                  + drought,
                  random = ~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, data = d3)
lmm1 = update(lmm1)
test.asreml(lmm1) 

# test the significance of interaction difference
# separately for each selection treatment
d3d = subset(d3, drought == "D")
d3r = subset(d3, drought == "R")

lmm1_1 = asreml.nvc(Ndiff ~
                      Block,
                    random = ~sp_comp,
                    data = d3d)
test.asreml(lmm1_1)

lmm1_2 = asreml.nvc(Ndiff ~
                      Block,
                    random = ~sp_comp,
                    data = d3r)
test.asreml(lmm1_2)
