##############################################
#
# Effects of drought selection on 
# biodiversity effects on productivity
# Corresponds to the results in Fig. 2, 
# Table 1 and Supplementary Table 3
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-01-02 
#
##############################################

rm(list = ls())
library(asreml)
library(pascal)

# read data of net biodiversity effects (NE) 
# on productivity, which were partitioned
# into complementarity effects (CE) and
# selection effects (SE)
dat = read.csv("div-productivity_data.csv")
# note: Fig. 2 was produced from the raw data
# in this csv file by calculating the average
# diversity effect and its additive components
# for each species composition of each selection
# treatment in each harvest time.
str(dat)
summary(dat[,c("NE", "CE", "SE")])
table(dat$Block)
nlevels(as.factor(dat$sp_comp))
# biodiversity effects were calculated
# separately for each harvest: pre drought,
# during drought and post drought.
table(dat$time)

###################################
# 1. Pre-drought
d1 = subset(dat, time == "Pre-drought")
str(d1)

#-------------------------
#     NE
#-------------------------
tapply(d1$NE, d1$drought, mean, na.rm = T)
sum(!is.na(d1$NE))

# effects of drought selection on NE
lmm1 = asreml.nvc(NE ~
                Block
              + drought,
              random = ~ sp_comp
              + sp_comp:drought,
              keep.order = T, data = d1)
lmm1 = update(lmm1)
test.asreml(lmm1) 

# test the significance of biodiversity effects
# separately for each selection treatment
# that is, the significance of "intercept"
d1d = subset(d1, drought == "D")
d1r = subset(d1, drought == "R")
sum(!is.na(d1d$NE))
sum(!is.na(d1r$NE))
lmm2 = asreml.nvc(NE ~
                Block,
              random = ~sp_comp,
              data = d1d)
test.asreml(lmm2)

lmm3 = asreml.nvc(NE ~
                Block,
              random = ~sp_comp,
              data = d1r)
test.asreml(lmm3)

#-------------------------
#     CE
#-------------------------
tapply(d1$sqrt_CE, d1$drought, mean, na.rm = T)
sum(!is.na(d1$sqrt_CE))
sum(!is.na(d1d$sqrt_CE))
sum(!is.na(d1r$sqrt_CE))

# effects of drought selection on CE
lmm1 = asreml.nvc(sqrt_CE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d1)
test.asreml(lmm1)

# test the significance of biodiversity effects
# separately for each selection treatment
lmm2 = asreml.nvc(sqrt_CE ~
                Block,
              random = ~sp_comp,
              data = d1d)
test.asreml(lmm2)

lmm3 = asreml.nvc(sqrt_CE ~
                Block,
              random = ~sp_comp,
              data = d1r)
test.asreml(lmm3)

#-------------------------
#     SE
#-------------------------
tapply(d1$sqrt_SE, d1$drought, mean, na.rm = T)
sum(!is.na(d1$sqrt_SE))
sum(!is.na(d1d$sqrt_SE))
sum(!is.na(d1r$sqrt_SE))

# effects of drought selection on SE
lmm1 = asreml(sqrt_SE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d1)
test.asreml(lmm1)

# test the significance of biodiversity effects
# separately for each selection treatment
lmm2 = asreml.nvc(sqrt_SE ~
                Block,
              random = ~sp_comp,
              data = d1d)
test.asreml(lmm2) 

lmm3 = asreml.nvc(sqrt_SE ~
                Block,
              random = ~sp_comp,
              data = d1r)
test.asreml(lmm3)

###############################################
# 2. During-drought
d2 = subset(dat, time == "Drought")
str(d2)

#-------------------------
#     NE
#-------------------------
tapply(d2$NE, d2$drought, mean, na.rm = T)
sum(!is.na(d2$NE))

# effects of drought selection on NE
lmm1 = asreml.nvc(NE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d2)
lmm1 = update(lmm1)
test.asreml(lmm1) 

# test the significance of biodiversity effects
# separately for each selection treatment
d2d = subset(d2, drought == "D")
d2r = subset(d2, drought == "R")
sum(!is.na(d2d$NE))
sum(!is.na(d2r$NE))
lmm2 = asreml.nvc(NE ~
                Block,
              random = ~sp_comp,
              data = d2d)
test.asreml(lmm2) 

lmm3 = asreml.nvc(NE ~
                Block,
              random = ~sp_comp,
              data = d2r)
test.asreml(lmm3) 

#-------------------------
#     CE
#-------------------------
tapply(d2$sqrt_CE, d2$drought, mean, na.rm = T)
sum(!is.na(d2$sqrt_CE))
sum(!is.na(d2d$sqrt_CE))
sum(!is.na(d2r$sqrt_CE))

lmm1 = asreml(sqrt_CE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d2)
lmm1 = update(lmm1)
test.asreml(lmm1) 

lmm2 = asreml.nvc(sqrt_CE ~
                Block,
              random = ~sp_comp,
              data = d2d)
test.asreml(lmm2) 

lmm3 = asreml.nvc(sqrt_CE ~
                Block,
              random = ~sp_comp,
              data = d2r)
lmm3 = update(lmm3)
test.asreml(lmm3)
# denDF from lmm3 is unrealistic and problematic
# so that we use aov below

aov3 = aov(terms(sqrt_CE ~
                   Block +
                   sp_comp,
                 keep.order=T),
           data = d2r)
summary(aov3, intercept = T)
# when testing the significance of intercept,
# we use species composition (sp_comp) as error term
aov.ftest(aov3, (Intercept)~sp_comp, table=T)

#-------------------------
#     SE
#-------------------------
tapply(d2$sqrt_SE, d2$drought, mean, na.rm = T)
sum(!is.na(d2$sqrt_SE))
sum(!is.na(d2d$sqrt_SE))
sum(!is.na(d2r$sqrt_SE))

lmm1 = asreml.nvc(sqrt_SE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d2)
test.asreml(lmm1) 

lmm2 = asreml(sqrt_SE ~
                Block,
              random = ~sp_comp,
              data = d2d)
test.asreml(lmm2)

lmm3 = asreml(sqrt_SE ~
                Block,
              random = ~sp_comp,
              data = d2r)
test.asreml(lmm3) 

###############################################
# 3. Post-drought
d3 = subset(dat, time == "Post-drought")
str(d3)

#-------------------------
#     NE
#-------------------------
tapply(d3$NE, d3$drought, mean, na.rm = T)
sum(!is.na(d3$NE))

lmm1 = asreml.nvc(NE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d3)
lmm1 = update(lmm1)
test.asreml(lmm1) 

d3d = subset(d3, drought == "D")
d3r = subset(d3, drought == "R")
sum(!is.na(d3d$NE))
sum(!is.na(d3r$NE))

lmm2 = asreml.nvc(NE ~
                Block,
              random = ~ sp_comp,
              data = d3d)
test.asreml(lmm2) 

lmm3 = asreml.nvc(NE ~
                Block,
              random = ~ sp_comp,
              data = d3r)
lmm3 = update(lmm3)
test.asreml(lmm3) 

#-------------------------
#     CE
#-------------------------
tapply(d3$sqrt_CE, d3$drought, mean, na.rm = T)
sum(!is.na(d3$sqrt_CE))
sum(!is.na(d3d$sqrt_CE))
sum(!is.na(d3r$sqrt_CE))

lmm1 = asreml.nvc(sqrt_CE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d3)
# lmm1 using asreml.nvc or asreml cause problem,
# so that we use aov instead

aov1 = aov(terms(sqrt_CE ~
                   Block +
                   sp_comp +
                   drought +
                   drought:sp_comp,
                 keep.order = T),
           data = d3)
summary(aov1)
aov.ftest(aov1, drought ~ drought:sp_comp, 
          table = T)

lmm2 = asreml.nvc(sqrt_CE ~
                Block,
              random = ~ sp_comp,
              data = d3d)
test.asreml(lmm2)

lmm3 = asreml.nvc(sqrt_CE ~
                Block,
              random = ~ sp_comp,
              data = d3r)
test.asreml(lmm3) 

#-------------------------
#     SE
#-------------------------
tapply(d3$sqrt_SE, d3$drought, mean, na.rm = T)
sum(!is.na(d3$sqrt_SE))
sum(!is.na(d3d$sqrt_SE))
sum(!is.na(d3r$sqrt_SE))

lmm1 = asreml.nvc(sqrt_SE ~
                Block
              + drought,
              random = ~sp_comp
              + sp_comp:drought,
              keep.order = T, data = d3)
test.asreml(lmm1) 

lmm2 = asreml.nvc(sqrt_SE ~
                Block,
              random = ~ sp_comp,
              keep.order = T, data = d3d)
test.asreml(lmm2) 

lmm3 = asreml.nvc(sqrt_SE ~
                Block,
              random = ~ sp_comp,
              data = d3r)
test.asreml(lmm3)
