###########################################
#
# ANOVA for the effects of drought selection
# on the difference in stability indices
# between mixture and monoculture
# Corresponds to the results in Fig. 3, 
# and Supplementary Table 5
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-01-02
#
###########################################

rm(list = ls())
library(asreml)
library(pascal)

dat = read.csv("div-stability_data.csv")
str(dat)

# summary statistics
summary(dat$resist_NE)
summary(dat$recov_NE)
summary(dat$resil_NE)
d1 = dat[!is.na(dat$resist_NE),c("drought", "resist_NE")]
d2 = dat[!is.na(dat$recov_NE),c("drought", "recov_NE")]
d3 = dat[!is.na(dat$resil_NE),c("drought", "resil_NE")]
colnames(d1)[2] = "y"
colnames(d2)[2] = "y"
colnames(d3)[2] = "y"
d1$g = "a"
d2$g = "b"
d3$g = "c"
d = rbind(d1, d2, d3)
str(d)
(mu = tapply(d$y, list(d$g,
                       d$drought),
             mean, na.rm=T))

#------------------------------
#       1. Resistance
#------------------------------
d0 = subset(dat, !is.na(resist_NE))
nrow(d0)
summary(d0$biom1)
d0$log_biom1 = log(d0$biom1)

lmm1 = asreml.nvc(resist_NE ~
                    Block
                  + drought
                  + log_biom1,
                  random = ~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, 
                  data = d0)
test.asreml(lmm1) 

# test the significance of diversity effect
# on resistance for each selection treatment
# that is, the significance of "intercept"
dd0 = subset(d0, drought == "D")
rd0 = subset(d0, drought == "R")

lmm1_1 = asreml.nvc(resist_NE ~
                    Block
                  + log_biom1,
                  random = ~
                    sp_comp,
                  keep.order=T,data=dd0)
lmm1_1 = update(lmm1_1)
test.asreml(lmm1_1)

lmm1_2 = asreml.nvc(resist_NE ~
                      Block
                    + log_biom1,
                    random = ~
                      sp_comp,
                    keep.order=T,data=rd0)
test.asreml(lmm1_2)

#------------------------------
#  2. Recovery
#------------------------------
d0 = subset(dat, !is.na(recov_NE))
nrow(d0)
summary(d0$biom1)
d0$log_biom1 = log(d0$biom1)

aov2 = aov(terms(recov_NE ~
                   Block
                 + log_biom1
                 + sp_comp
                 + drought
                 + drought:sp_comp,
                 #+ log_biom1,
                 keep.order = T), 
           data = d0)
summary(aov2) 
m = aov.ftest(aov2, drought~drought:sp_comp, table = T)
m[,"F"] = as.character(m[,"F"])
m[,"P"] = as.character(m[,"P"])
out[2,] = as.numeric(m[,c("df","ddf","F","P")])
n2 = sum(!is.na(d0$recov_NE))

lmm2 = asreml.nvc(recov_NE ~
                    Block
                  + drought
                  + log_biom1,
                  random = ~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, 
                  data = d0)
lmm2 = update(lmm2)
lmm2 = update(lmm2)
test.asreml(lmm2) 

# denDF of drought from lmm2 is unrealistic
# and problematic so that we use aov instead
aov2 = aov(terms(recov_NE ~
                   Block
                 + sp_comp
                 + drought
                 + drought:sp_comp
                 + log_biom1,
                 keep.order = T), 
           data = d0)
summary(aov2) 
# when testing the significance drought, we
# use drought:sp_comp as error term
(m = aov.ftest(aov2, 
              drought~drought:sp_comp, 
              table=T))

dd0 = subset(d0, drought == "D")
rd0 = subset(d0, drought == "R")

lmm2_1 = asreml.nvc(recov_NE ~
                      Block
                    + log_biom1,
                    random = ~
                      sp_comp,
                    keep.order=T,data=dd0)
test.asreml(lmm2_1)

lmm2_2 = asreml.nvc(recov_NE ~
                      Block
                    + log_biom1,
                    random = ~
                      sp_comp,
                    keep.order=T,data=rd0)
test.asreml(lmm2_2)

#------------------------------
#  3. Resilience
#------------------------------
d0 = subset(dat, !is.na(resil_NE))
nrow(d0)
summary(d0$biom1)
d0$log_biom1 = log(d0$biom1)

lmm3 = asreml.nvc(resil_NE ~
                    Block
                  + drought
                  + log_biom1,
                  random = ~
                    sp_comp
                  + sp_comp:drought,
                  keep.order = T, 
                  data = d0)
lmm3 = update(lmm3)
test.asreml(lmm3) 

dd0 = subset(d0, drought == "D")
rd0 = subset(d0, drought == "R")

lmm3_1 = asreml.nvc(resil_NE ~
                      Block
                    + log_biom1,
                    random = ~
                      sp_comp,
                    keep.order=T,data=dd0)
test.asreml(lmm3_1)

lmm3_2 = asreml.nvc(resil_NE ~
                      Block
                    + log_biom1,
                    random = ~
                      sp_comp,
                    keep.order=T,data=rd0)
test.asreml(lmm3_2)
