##############################################
#
# Effects of drought selection on 
# trait values
# Corresponds to the results in Supplementary
# Figs. 5-7 and Supplementary Table 9
# Programmer: Yuxin Chen
# Contact: yuxin.chen@xmu.edu.cn
# Version: 2022-01-02 
#
##############################################

rm(list = ls())
library(asreml)
library(pascal)

dat = read.csv("trait_data.csv")
str(dat)

#--------------------------
#
#   1. LMA
#
#--------------------------
summary(dat$LMA)
dat0 = subset(dat, !is.na(dat$LMA))
nrow(dat0)

# test the effects of drought selection
# across species
m1 = asreml.nvc(log(LMA) ~ Block
                + drought,
                random = ~
                  sp
                + sp:drought,
                keep.order = T, 
                data = dat0)
m1 = update(m1)
test.asreml(m1) 

# test the interactive effects of drought 
# selection and species
m2 = aov(terms(log(LMA) ~
                 Block +
                 sp +
                 drought +
                 sp:drought,
               keep.order = T),
         data = dat0)
summary(m2)

#-----------------
#
# 2.  LA
#
#-----------------
summary(dat$LA)
dat0 = subset(dat, !is.na(dat$LA))
nrow(dat0) 

m1 = asreml.nvc(log(LA) ~ Block
                + drought,
                random = ~
                  sp
                + sp:drought,
                keep.order = T, 
                data = dat0)
m1 = update(m1)
test.asreml(m1) 

m2 = aov(terms(log(LA) ~
                 Block +
                 sp +
                 drought +
                 sp:drought,
               keep.order = T),
         data = dat0)
summary(m2)

#----------------------------------------
#
# 3. SPAD (relative chlorophyll content)
#
#----------------------------------------
summary(dat$SPAD)
dat0 = subset(dat, !is.na(dat$SPAD))
nrow(dat0)

m1 = asreml.nvc(SPAD ~ Block
                + drought,
                random = ~
                  sp
                + sp:drought,
                keep.order = T, 
                data = dat0)
m1 = update(m1)
test.asreml(m1) 

m2 = aov(terms(SPAD ~
                 Block +
                 sp +
                 drought +
                 sp:drought,
               keep.order = T),
         data = dat0)
summary(m2)

#----------------------------------
#
# 4. Leaf osmometric potential (osmo)
#
#----------------------------------
dat0 = subset(dat, !is.na(log_osmo))
summary(dat0$log_osmo)
nrow(dat0)

m1 = asreml.nvc(log_osmo ~ Block
                + drought,
                random = ~
                  sp
                + sp:drought,
                keep.order = T, 
                data = dat0)
test.asreml(m1) 

m2 = aov(terms(log_osmo ~
                   Block +
                   sp +
                   drought +
                   sp : drought,
                 keep.order = T),
           data = dat0)
summary(m2)

#---------------------------------------
#
# 5. Stomatal conductance before drought
#
#---------------------------------------
dat0 = subset(dat, !is.na(log_cond_pre))
summary(dat0$log_cond_pre)
nrow(dat0)

m1 = asreml.nvc(log_cond_pre ~ Block
                + drought,
                random = ~
                  sp
                + sp:drought,
                keep.order = T, 
                data = dat0)
m1 = update(m1)

# problems occur in fitting m1, so that 
# we use aov instead to test the significance
# of drought selection using sp:drought as 
# error term

m2 = aov(terms(log_cond_pre ~
                   Block +
                   sp +
                   drought +
                   sp : drought,
                 keep.order = T),
           data = dat0)
summary(m2)
aov.ftest(m2, drought~sp:drought, table=T)

#---------------------------------------
#
# 6. Stomatal conductance post drought
#
#---------------------------------------
dat0 = subset(dat, !is.na(log_cond_post))
summary(dat0$log_cond_post)
nrow(dat0)
table(dat0$Block)
# only from one block

m1 = asreml.nvc(log_cond_post ~ drought,
                random = ~
                  sp
                + sp:drought,
                data = dat0)
m1 = update(m1)
test.asreml(m1) 

m2 = aov(terms(log_cond_post ~
                   sp +
                   drought +
                   sp : drought,
                 keep.order = T),
           data = dat0)
summary(m2)

#----------------------------------
#
# 7. Root-shoot ratio
#
#----------------------------------
dat0 = subset(dat, !is.na(lrs))
summary(dat0$lrs)
nrow(dat0)

m1 = asreml.nvc(lrs ~ Block
                + drought,
                random = ~
                  sp
                + sp:drought,
                keep.order = T, 
                data = dat0)
m1 = update(m1)
test.asreml(m1) 

m2 = aov(terms(lrs ~
                   Block +
                   sp +
                   drought +
                   sp : drought,
                 keep.order = T),
           data = dat0)
summary(m2)
